//
//  SSAllowedListFilter.java
//  SwitchableString52
//
//  Created by Paul Suh on Sun Sep 07 2003.
//
/*
 
 Copyright (c) 2003 Paul Suh. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are
 met:
 
 * Redistributions of source code must retain the above copyright
 notice, this list of conditions and the following disclaimer.
 
 * Redistributions in binary form must reproduce the above copyright
 notice, this list of conditions and the following disclaimer in the
 documentation and/or other materials provided with the distribution.
 
 * Neither the name of the site goodeast.com nor the names of its
 contributors may be used to endorse or promote products derived from
 this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 */

package com.goodeast.webobjects.switchablestring;

import com.webobjects.foundation.*;


/** 
 * Checks tags against an allowed list. If the tag is on the allowed
 * list it is not escaped, otherwise it is escaped.
 */
public class SSAllowedTagsFilter extends SSHTMLFilter {

    // Instance variables
    /** List of allowed tags. Any tags not on this list should be escaped. 
     */
    NSArray _allowedTags;

    /** Creates a new SSAllowedTagsFilter. If allowedTags is null, the list of allowed tags is set to an empty NSArray.
     * 
     * @param allowedTags Array of allowed tags
     */
    SSAllowedTagsFilter( NSArray allowedTags ) {

        if ( allowedTags == null )
            _allowedTags = new NSArray();
        else
            _allowedTags = allowedTags;
    }

    /** 
     * Returns true if <CODE>tag</CODE> is not in the allowed list.
     * 
     * @param tag Tag to be checked
     * @return True if tag should be escaped, false otherwise
     */
    public boolean tagShouldBeEscaped( String tag ) {

        return !_allowedTags.containsObject( tag );

    }
}
