//
//  SSParentAssociation.java
//  SwitchableString52
//
//  Created by Paul Suh on Tue Sep 09 2003.
/*
 
 Copyright (c) 2003 Paul Suh. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are
 met:
 
 * Redistributions of source code must retain the above copyright
 notice, this list of conditions and the following disclaimer.
 
 * Redistributions in binary form must reproduce the above copyright
 notice, this list of conditions and the following disclaimer in the
 documentation and/or other materials provided with the distribution.
 
 * Neither the name of the site goodeast.com nor the names of its
 contributors may be used to endorse or promote products derived from
 this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 */

package com.goodeast.webobjects.switchablestring;


import com.webobjects.appserver.*;
import com.webobjects.foundation.*;


/** 
 * This class is used to work around the fact that two of the elements being
 * subclassed are in fact subclasses of WOComponent, not WODynamicElement. As a
 * result, they don't get an array of associations in their constructor,only
 * bindings to the parent component. However, most of the code works correctly
 * if it is passed WOAssociations, so this class serves as glue.
 */
public class SSParentAssociation extends WOAssociation {

    
    /** The name of the binding for this Association.
     */
    protected String _bindingName;
    
    /** Creates a new SSParentAssociation which can be used to access the binding bindingName.
     * 
     * @param bindingName The name of the binding used by this association
     */
    public SSParentAssociation( String bindingName ) {
        super();

        _bindingName = bindingName;
    }

    /** Conformance to subclassing rules for WOAssociation.
     * 
     * @param aComponent The WOComponent in which this association should be 
     *     evaluated.
     * @return The name of the binding for this association.
     */
    public String bindingInComponent( WOComponent aComponent ) {

        return _bindingName;
    }

    /** Logs an error and continues, as we can't know the keyPath used by this binding based on the public WOComponent API's.
     * 
     * @return Always returns the string "unknown".
     */
    public String keyPath() {

        NSLog.err.appendln( "keyPath called in SSParentAssociation with binding:" + _bindingName );
        return "unknown";
    }

    /** Returns the value for the binding evaluated in aComponent's <b>parent</b> component.
     * 
     * @param aComponent The WOComponent whose parent the binding should be 
     *     evaluated in.
     * @return The value for the binding.
     */
    public Object valueInComponent( WOComponent aComponent ) {

        return aComponent.valueForBinding( _bindingName );
    }

    /** Sets the value for this binding in aComponent's <b>parent</b> component.
     * 
     * @param value The value to be set.
     * @param aComponent The component whose parent should have the 
     *     binding's value set. 
     */
    public void setValue( Object value, WOComponent aComponent ) {

        aComponent.setValueForBinding( value, _bindingName );
    }

}
